# librtc - Manipuler le temps, pas l'espace

|                                                                                                                                                                                     |
| :---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------: |
| [Ce projet est sur la forge PC](http://git.planet-casio.com/cakeisalie5/librtc)                                                                                                     |
| Version actuelle : [0.3](http://git.planet-casio.com/cakeisalie5/librtc/tags/0.3) ([télécharger](http://git.planet-casio.com/cakeisalie5/librtc/repository/archive.tar.gz?ref=0.3)) |

## Introduction

Comme j'étais dans un effort de simplifier encore le développement sous Linux avec des libs statiques et que je bidouillais le C-Engine, j'ai remarqué qu'il avait des fonctions que je trouvais pas très propres pour bidouiller la RTC : c'est pourquoi j'ai décidé d'en faire une lib, pour centraliser les efforts.

## La RTC, kézako ?

La Real-Time Clock est un simple compteur incrémenté régulièrement (64 fois par seconde) par un oscillateur. C'est un module qui tourne indépendemment du processeur.

Histoire de le préciser, cet oscillateur n'est pas magique, et a besoin de batterie pour continuer de tourner. Si vous enlevez les piles ou si elles sont mortes, il arrêtera de tourner, et peut-être que le compteur se réinitialisera : dans tous les cas, celle-ci peut se dérégler.

De plus, il n'y a pas de gestion native du fuseau horaire, ni même au niveau du système, donc l'heure est en GMT par défaut. Donc gardez à l'esprit, si votre addin utilise cette lib, qu'il y a des chances que la RTC contienne n'importe quoi à son lancement. Demandez à l'utilisateur de confirmer l'heure au lancement si vous souhaitez ne pas avoir de surprises.

## Interface

Pour utiliser la librtc, pensez à inclure son header avec `#include <rtc.h>` et à l'ajouter au linker avec `-lrtc` (une fois installée).

Avant toute utilisation de la RTC, il faut l'initialiser :

	rtc_init();

Cette initialisation ne doit être faite qu'**une seule fois** pendant tout le programme. Elle retourne si tout va bien, i.e. si le microprocesseur est reconnu (la librtc se servant directement du matériel, sans appels système).

Ensuite, pour obtenir la date, prenez déjà connaissance de la structure suivante :

	typedef struct {
		int hz64;
		int sec;
		int min;
		int hour;
		int wday;
		int day;
		int month;
		int year;
	} rtc_date_t;

Ensuite, pour obtenir la date actuelle de la RTC, il vous suffit de la récupérer via :

	rtc_date_t date = rtc_getdate();

Pour obtenir le timestamp (i.e. le nombre de secondes passées depuis [le 1er janvier 1970 à minuit](https://fr.wikipedia.org/wiki/Epoch)), il vous suffit de faire :

	unsigned int time = rtc_gettime();

Maintenant, si ce que vous voulez faire, c'est régler l'heure, deux fonctions risquent de vous intéresser :

	rtc_settime(time); // régler le temps à l'aide d'un timestamp UNIX
	rtc_setdate(date); // régler le temps à l'aide d'une date

Je vous conseille d'utiliser les fonctions getdate et setdate que celles utilisant des timestamps, étant donné que le compteur de la RTC est sous forme de date -- cela étant, vous avez le choix.

Quelques fonctions de conversion sont également disponibles :

	rtc_date_t date2 = rtc_dateoftime(time);
	unsigned int time2 = rtc_timeofdate(date);

## Pour le moment, c'est tout.

A priori, pas d'autres fonctions à venir, mais surtout des tests ! Pour passer à une version stable (la 1.0 ?), il faut vraiment qu'on checke/corrige.
